corium.api

Synchronous JVM Clojure API for Corium.

This namespace has the same operations as corium.api.async. It blocks on one-shot result channels and throws errors from the Java client.

Synchronous JVM Clojure API for Corium.

This namespace has the same operations as corium.api.async. It blocks on
one-shot result channels and throws errors from the Java client.
raw docstring

corium.api.async

Asynchronous JVM Clojure API for Corium.

Operations backed by CompletableFuture return a one-shot core.async channel. A successful channel yields its value; a failed channel yields the Throwable. Successful nil results close without yielding a value. Use <? in a go block to rethrow failures.

Boundary values are recursively translated between ordinary Clojure data and the Java client's Keyword, Symbol, EdnList, and Tagged representations.

Asynchronous JVM Clojure API for Corium.

Operations backed by CompletableFuture return a one-shot core.async channel.
A successful channel yields its value; a failed channel yields the Throwable.
Successful nil results close without yielding a value. Use `<?` in a go block
to rethrow failures.

Boundary values are recursively translated between ordinary Clojure data and
the Java client's Keyword, Symbol, EdnList, and Tagged representations.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries