corium.api

Synchronous JVM Clojure API for Corium.

This namespace has the same operations as corium.api.async. It blocks on one-shot result channels and throws errors from the Java client.

Synchronous JVM Clojure API for Corium.

This namespace has the same operations as corium.api.async. It blocks on
one-shot result channels and throws errors from the Java client.
raw docstring

as-ofclj

(as-of db t)
source

available-storage-backendsclj

(available-storage-backends)
source

basis-tclj

(basis-t db)
source

closeclj

(close peer)
source

connectclj

(connect config)
source

databaseclj

(database peer-or-db)
source

database-nameclj

(database-name peer-or-db)
source

datomsclj

(datoms db index)
(datoms db index components)
(datoms db index components limit)
source

dbclj

(db peer)
source

direct-storageclj

(direct-storage)
(direct-storage cache)
source

historyclj

(history db)
source

pullclj

(pull db pattern entity)
source

qclj

(q db query & arguments)
source

queryclj

(query db query)
(query db query arguments)
(query db query arguments fuel)
(query db query additional-databases arguments fuel)
source

segment-cacheclj

(segment-cache directory capacity-bytes)
(segment-cache directory capacity-bytes memory-capacity-bytes)
source

sinceclj

(since db t)
source

statsclj

(stats db)
source

syncclj

(sync peer)
source

transactclj

(transact peer transaction-data)
source

cljdoc builds & hosts documentation for Clojure/Script libraries