Synchronous JVM Clojure API for Corium.
This namespace has the same operations as corium.api.async. It blocks on one-shot result channels and throws errors from the Java client.
Synchronous JVM Clojure API for Corium. This namespace has the same operations as corium.api.async. It blocks on one-shot result channels and throws errors from the Java client.
Asynchronous JVM Clojure API for Corium.
Operations backed by CompletableFuture return a one-shot core.async channel.
A successful channel yields its value; a failed channel yields the Throwable.
Successful nil results close without yielding a value. Use <? in a go block
to rethrow failures.
Boundary values are recursively translated between ordinary Clojure data and the Java client's Keyword, Symbol, EdnList, and Tagged representations.
Asynchronous JVM Clojure API for Corium. Operations backed by CompletableFuture return a one-shot core.async channel. A successful channel yields its value; a failed channel yields the Throwable. Successful nil results close without yielding a value. Use `<?` in a go block to rethrow failures. Boundary values are recursively translated between ordinary Clojure data and the Java client's Keyword, Symbol, EdnList, and Tagged representations.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |